from gcs_cli.helpers import requires_login
from gcs_cli.parsing import (
    EXPLICIT_NULL,
    collection_create_and_update_params,
    collection_id_arg,
    globus_command,
)
from gcs_cli.prettyprint import FORMAT_TEXT_RECORD, formatted_print
from gcs_cli.sdk_client.data import CollectionDocument
from gcs_cli.services.gcs import get_client


@globus_command("update", short_help="Update a Collection definition")
@collection_id_arg
@collection_create_and_update_params(create=False)
@requires_login
def collection_update(collection_id, **kwargs):
    """
    Update a Collection on the Endpoint into which the GCS CLI is logged in.
    """
    client = get_client()

    # convert keyword args as follows:
    # - filter out Nones
    # - pass through EXPLICIT_NULL as None
    converted_kwargs = {
        k: (v if v != EXPLICIT_NULL else None)
        for k, v in kwargs.items()
        if v is not None
    }
    doc = CollectionDocument(DATA_TYPE="collection#1.0.0", **converted_kwargs)

    res = client.update_collection(collection_id, doc)

    formatted_print(res, fields=[("code", "code")], text_format=FORMAT_TEXT_RECORD)
