import time

import globus_sdk

from gcs_cli.config import internal_auth_client, token_storage_adapter
from gcs_cli.helpers import print_command_hint, requires_login
from gcs_cli.parsing import globus_command
from gcs_cli.prettyprint import formatted_print
from gcs_cli.services.auth import get_client


@globus_command("show", short_help="Show your current auth session")
@requires_login
def session_show():
    """List all identities in your current CLI auth session."""
    # get a token to introspect, refreshing if neccecary
    user_client = get_client()
    user_client.authorizer.check_expiration_time()
    access_token = token_storage_adapter().read_as_dict()["auth.globus.org"][
        "access_token"
    ]

    app_client = internal_auth_client()
    res = app_client.oauth2_token_introspect(access_token, include="session_info")

    session_info = res.get("session_info", {})
    authentications = session_info.get("authentications") or {}

    # resolve ids to human readable usernames
    resolved_ids = globus_sdk.IdentityMap(user_client, list(authentications))

    # put the nested dicts in a format table output can work with
    # while also converting vals into human readable formats
    list_data = [
        {
            "id": key,
            "username": resolved_ids.get(key, {}).get("username"),
            "auth_time": time.strftime(
                "%Y-%m-%d %H:%M %Z", time.localtime(vals["auth_time"])
            ),
        }
        for key, vals in authentications.items()
    ]

    print_command_hint(
        "For information on your primary identity or full identity set see\n"
        "  globus-connect-server whoami\n"
    )

    formatted_print(
        list_data,
        json_converter=lambda x: session_info,
        fields=[("Username", "username"), ("ID", "id"), ("Auth Time", "auth_time")],
    )
