import sys

import click

from gcs_cli.error_handler import handle_excinfo
from gcs_cli.parsing.stateful_options import explicit_host_option, format_option
from gcs_cli.version import __version__ as version


def _common_options(f, disable_opts):
    if "format" not in disable_opts:
        f = format_option(f)
    if "version" not in disable_opts:
        f = click.version_option(version)(f)
    if "help" not in disable_opts:
        f = click.help_option("-h", "--help")(f)
    if "explicit_host" not in disable_opts:
        f = explicit_host_option(f)
    return f


def globus_command(*args, **kwargs):
    """
    A helper for decorating commands a-la `click.command`, but pulling the help string
    from `<function>.__doc__` by default. Fancy!
    """
    disable_opts = kwargs.pop("disable_options", [])

    def _inner_decorator(func):
        if "help" not in kwargs:
            kwargs["help"] = func.__doc__

        return _common_options(click.command(*args, **kwargs)(func), disable_opts)

    return _inner_decorator


class TopLevelGroup(click.Group):
    def invoke(self, ctx):
        try:
            return super().invoke(ctx)
        except Exception:
            handle_excinfo(sys.exc_info())


def globus_group(*args, **kwargs):
    disable_opts = kwargs.pop("disable_options", [])
    top_level_group = kwargs.pop("top_level", False)

    if top_level_group:
        kwargs["cls"] = TopLevelGroup

    def _inner_decorator(func):
        if "help" not in kwargs:
            kwargs["help"] = func.__doc__

        return _common_options(click.group(*args, **kwargs)(func), disable_opts)

    return _inner_decorator
