from typing import List

from globus.manager.constants import ConfigurationObjectTag
import globus.manager.api.errors as errors
from . import UserCredential


class CephUserCredential(UserCredential):
    POLICY_DATA_TYPE = "ceph_user_credential_policies#1.0.0"
    __mapper_args__ = {
        "polymorphic_identity": (
            ConfigurationObjectTag.USER_CREDENTIAL.name
            + "1b6374b0-f6a4-4cf7-a26f-f262d9c6ca72"
        )
    }
    connector_properties = []  # type: List[str]

    def __init__(self, appsync_data=None, doc=None, storage_gateway=None):
        if doc:
            username = doc["username"]
            display_name = storage_gateway.get_user_display_name(username)
            if display_name is None:
                raise errors.InvalidUserError(username)

            policies = doc.get("policies")
            if not policies:
                policies = {"DATA_TYPE": self.POLICY_DATA_TYPE}
            doc = {
                **doc,
                **{
                    "display_name": display_name,
                    "invalid": doc.get("invalid", False),
                    "deleted": False,
                    "provisioned": True,
                    "policies": policies,
                },
            }

        super().__init__(
            appsync_data=appsync_data, doc=doc, storage_gateway=storage_gateway
        )

    def patch(self, **doc):
        # display_name is computed from ceph api, so disallow changes
        display_name = doc.pop("display_name", None)
        if display_name and getattr(self, "display_name", None) != display_name:
            raise ValueError("Cannot change display_name via PATCH")
        elif not display_name:
            display_name = getattr(self, "display_name", None)
        doc["display_name"] = display_name
        super().patch(**doc)

    def put(self, **doc):
        # display_name is computed from ceph api, so disallow changes
        display_name = doc.pop("display_name", None)
        if display_name and getattr(self, "display_name", None) != display_name:
            raise ValueError("Cannot change display_name via PUT")
        elif not display_name:
            display_name = getattr(self, "display_name", None)
        doc["display_name"] = display_name
        super().put(**doc)

    @property
    def connector_id(self):
        return "1b6374b0-f6a4-4cf7-a26f-f262d9c6ca72"

    @connector_id.setter
    def connector_id(self, value):
        if value and str(value) != self.connector_id:
            raise ValueError("Immutable property connector_id")

    def __repr__(self):
        return "<CephUserCredential {}>".format(self.id)
