import ipaddress

import marshmallow as ma

from globus.manager.constants import NodeStatus
from .data_type import DataTypeSchema
from ..patch_schema import create_patch_schema
from ..enum_field import EnumField


class NodeSchema(ma.Schema):
    _DATA_TYPE = "node#1.0.0"
    DATA_TYPE = ma.fields.String(
        required=True,
        allow_none=False,
        default=_DATA_TYPE,
        validate=[ma.validate.Equal(_DATA_TYPE)],
    )
    id = ma.fields.UUID()
    ip_addresses = ma.fields.List(ma.fields.String, required=True)

    incoming_port_range = ma.fields.List(
        ma.fields.Int(validate=[ma.validate.Range(min=0, max=2 ** 16)]),
        validate=[ma.validate.Length(equal=2)],
        required=False,
    )

    outgoing_port_range = ma.fields.List(
        ma.fields.Int(validate=[ma.validate.Range(min=0, max=2 ** 16)]),
        validate=[ma.validate.Length(equal=2)],
        required=False,
    )

    status = EnumField(enum_class=NodeStatus, required=True)

    @ma.validates("ip_addresses")
    def validate_ip_addresses(self, data, **kwargs):
        if data:
            try:
                for i in data:
                    ipaddress.ip_address(i)
            except Exception as e:
                raise ma.ValidationError(str(e))


node_schema = NodeSchema()
node_patch_schema = create_patch_schema(NodeSchema)

DataTypeSchema.register_schema(node_schema)
