import marshmallow as ma

from ..enum_field import EnumField
from globus.manager.constants import ConfigurationObjectTag


class ConfigurationObjectSchema(ma.Schema):
    owner_id = ma.fields.UUID()
    id = ma.fields.Str()
    tag = EnumField(enum_class=ConfigurationObjectTag)
    serial = ma.fields.Int()
    created_at = ma.fields.AwareDateTime()
    updated_at = ma.fields.AwareDateTime()
    configuration = ma.fields.Str(allow_none=True)
    deleted = ma.fields.Bool(required=False, missing=False, allow_none=True)

    @ma.post_load
    def drop_owner_id(self, obj, **kwargs):
        if "owner_id" in obj:
            del obj["owner_id"]
        return obj

    @ma.post_load
    def fix_deleted(self, obj, **wargs):
        if obj["deleted"] is None:
            obj["deleted"] = False
        return obj


class ConfigurationObjectSetSchema(ma.Schema):
    # ma.EXCLUDE for __typename
    items = ma.fields.List(
        ma.fields.Nested(ConfigurationObjectSchema(unknown=ma.EXCLUDE))
    )
    next_page_token = ma.fields.Str(required=False, allow_none=True)


class AppSyncDataSchema(ma.Schema):
    """
    Schema for the Endpoint object in appsync, which includes all
    configuration objects for an endpoint
    """

    owner_id = ma.fields.UUID()
    deleted = ma.fields.Bool(required=False, missing=False, allow_none=True)
    # ma.EXCLUDE for __typename
    configuration_objects = ma.fields.Nested(
        ConfigurationObjectSetSchema(unknown=ma.EXCLUDE)
    )

    @ma.post_load
    def flatten_items(self, obj, **kwargs):
        obj["items"] = obj["configuration_objects"]["items"]
        del obj["configuration_objects"]["items"]

        return obj


appsync_data_schema = AppSyncDataSchema(unknown=ma.EXCLUDE)
