import random

from jwcrypto import jwk

import globus.manager.api.models as models
from globus.manager.utils.platform_info import PlatformInfo


def EndpointV53(client_id: str, host_endpoint_id: str, **kwargs) -> models.Endpoint:
    configuration_hash = {
        "DATA_TYPE": "endpoint_config#1.0.0",
        "id": client_id,
        "domain_index": random.randint(1, 2 ** 16),
        "oauth_state_key": jwk.JWK.generate(kty="oct", size=256).get_op_key(),
        "fingerprint": PlatformInfo().fingerprint(),
        "public": kwargs.get("public", True),
        "endpoint_id": kwargs["id"],
        "display_name": kwargs.get("display_name"),
        "subscription_id": kwargs.get("subscription_id"),
        "network_use": kwargs.get("network_use", "normal"),
        "allow_udt": False,
    }
    if configuration_hash["network_use"] == "custom":
        configuration_hash["max_concurrency"] = kwargs.get("max_concurrency")
        configuration_hash["preferred_concurrency"] = kwargs.get(
            "preferred_concurrency"
        )
        configuration_hash["max_parallelism"] = kwargs.get("max_parallelism")
        configuration_hash["preferred_parallelism"] = kwargs.get(
            "preferred_parallelism"
        )

    if "organization" in kwargs:
        configuration_hash["organization"] = kwargs.get("organization")

    keywords_str = kwargs.get("keywords")
    if keywords_str:
        configuration_hash["keywords"] = [s.strip() for s in keywords_str.split(",")]
    if kwargs.get("department"):
        configuration_hash["description"] = kwargs.get("description")
    if kwargs.get("contact_email"):
        configuration_hash["contact_email"] = kwargs.get("contact_email")
    if kwargs.get("contact_info"):
        configuration_hash["contact_info"] = kwargs.get("contact_info")
    if kwargs.get("info_link"):
        configuration_hash["info_link"] = kwargs.get("info_link")

    model = models.Endpoint(appsync_data={"configuration_hash": configuration_hash})
    model._endpoint_id = host_endpoint_id

    return model
