"""
Systemd Service Manager
"""

from __future__ import absolute_import
from subprocess import Popen, PIPE

from ..utils import log


def disable(service_name, periodic=False):
    """
    Disable the named service so that it will be started automatically
    on system boot.
    """
    ok = True
    if periodic:
        args = ["systemctl", "-q", "disable", service_name + ".timer"]
    else:
        args = ["systemctl", "-q", "disable", service_name + ".service"]

    log.debug("Executing {}".format(" ".join(args)))
    disabler = Popen(args, stdin=None)
    disabler.communicate()

    if ok:
        ok = disabler.returncode == 0

    return ok


def enable(service_name, periodic=False):
    """
    Enable the named service so that it will not be started automatically
    at system boot.
    """
    ok = True
    if periodic:
        args = ["systemctl", "-q", "enable", service_name + ".timer"]
    else:
        args = ["systemctl", "-q", "enable", service_name + ".service"]

    log.debug("Executing {}".format(" ".join(args)))
    enabler = Popen(args, stdin=None)
    enabler.communicate()
    ok = enabler.returncode == 0

    return ok


def start(service_name, periodic=False):
    """
    Start the named service.
    """
    ok = True
    if periodic:
        args = ["systemctl", "-q", "start", service_name + ".timer"]
    else:
        args = ["systemctl", "-q", "start", service_name + ".service"]

    log.debug("Executing {}".format(" ".join(args)))
    starter = Popen(args, stdin=None)
    starter.communicate()
    ok = starter.returncode == 0

    return ok


def stop(service_name, periodic=False):
    """
    Stop the named service.
    """
    ok = True
    if periodic:
        args = ["systemctl", "-q", "stop", service_name + ".timer"]
    else:
        args = ["systemctl", "-q", "stop", service_name + ".service"]

    stopper = Popen(args, stdin=None)
    stopper.communicate()
    ok = stopper.returncode == 0

    return ok


def status(service_name):
    """
    Return the status of the named service. Returns True if the service
    is running
    """
    status = Popen(
        ["systemctl", "-q", "status", service_name + ".service"],
        stdin=None,
        stdout=PIPE,
        stderr=PIPE,
    )
    status.communicate()

    return status.returncode == 0


def restart(service_name):
    """
    Restart the named service.
    """
    args = ["systemctl", "-q", "restart", service_name + ".service"]
    restarter = Popen(args, stdin=None)
    restarter.communicate()

    return restarter.returncode == 0


def reload(service_name):
    """
    Reload the named service's configuration.
    """
    args = ["systemctl", "-q", "reload", service_name + ".service"]
    reloader = Popen(args, stdin=None)
    reloader.communicate()

    return reloader.returncode == 0
